import { AxiosRequestConfig, AxiosResponse } from 'axios';
export declare abstract class Gateway {
    /** Qiitaのホストです */
    protected url: string;
    /** ユーザーのアクセストークンです */
    protected token: string;
    /** APIバージョンを示すパスです */
    protected version: string;
    /**
     * @param options オプショナルなパラメーター
     * @param options.url Qiitaのホストです
     * @param options.version APIバージョンを示すパスです
     * @param options.token ユーザーのアクセストークンです
     */
    constructor(options?: {
        url?: string;
        token?: string;
        version?: string;
    });
    /**
     * Qiita APIにアクセスするためのトークンを設定します
     * @param token トークン文字列
     * @return 何も返しません
     */
    setToken(token: string): void;
    /**
     * QiitaへのURLを設定します
     * @param url Qiitaのホスト
     * @return 何も返しません
     */
    setUrl(url: string): void;
    /**
     * Qiita APIへのパスを指定します．
     * @param version APIへのパスの文字列 (e.g. `/api/v2`)
     * @return 何も返しません
     */
    setVersion(version: string): void;
    /**
     * APIクライアントに設定されたトークンを返します
     * トークンの取得を行うには `Qiita.fetchAccessToken` をご利用ください。
     * @return 設定されたトークン
     */
    getToken: () => string;
    /**
     * APIクライアントに設定されたURLを返します
     * @return 設定されたURL
     */
    getUrl: () => string;
    /**
     * APIクライアントに設定されたバージョンを示すパスを返します
     * @return 設定されたパス
     */
    getVersion: () => string;
    /**
     * Fetch APIのラッパー関数です
     * @param url リクエストするURLです
     * @param options Fetch APIの第二引数に渡されるオプションです
     * @return パースされたJSONオブジェクトを解決するPromiseです
     */
    protected request<T>(options: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    /**
     * HTTP GETのラッパー関数です
     * @param url リクエストするURL
     * @param params クエリ文字列
     * @param options Fetch APIの第二引数になるオブジェクト
     */
    protected get<T>(url: string, params?: {}, options?: {}): Promise<AxiosResponse<T>>;
    /**
     * HTTP POSTのラッパー関数です
     * @param url リクエストするURL
     * @param body リクエストボディ
     * @param options Fetch APIの第二引数になるオブジェクト
     */
    protected post<T>(url: string, body?: {}, options?: {}): Promise<AxiosResponse<T>>;
    /**
     * HTTP PUTのラッパー関数です
     * @param url リクエストするURL
     * @param body リクエストボディ
     * @param options Fetch APIの第二引数になるオブジェクト
     */
    protected put<T>(url: string, body?: {}, options?: {}): Promise<AxiosResponse<T>>;
    /**
     * HTTP DELETEのラッパー関数です
     * @param url リクエストするURL
     * @param body リクエストボディ
     * @param options Fetch APIの第二引数になるオブジェクト
     */
    protected delete<T>(url: string, body?: {}, options?: {}): Promise<AxiosResponse<T>>;
    /**
     * HTTP PATCHのラッパー関数です
     * @param url リクエストするURL
     * @param body リクエストボディ
     * @param options Fetch APIの第二引数になるオブジェクト
     */
    protected patch<T>(url: string, body?: {}, options?: {}): Promise<AxiosResponse<T>>;
}
