import { Gateway } from './Gateway';
import * as options from './options';
import { AccessToken } from '../entities/AccessToken';
import { AuthenticatedUser } from '../entities/AuthenticatedUser';
import { Comment } from '../entities/Comment';
import { Item } from '../entities/Item';
import { Like } from '../entities/Like';
import { Project } from '../entities/Project';
import { Reaction } from '../entities/Reaction';
import { SearchTagResult, Tag } from '../entities/Tag';
import { Tagging } from '../entities/Tagging';
import { Team } from '../entities/Team';
import { TeamInvitation } from '../entities/TeamInvitation';
import { Template } from '../entities/Template';
import { User } from '../entities/User';
export declare class Qiita extends Gateway {
    /**
     * Qiita APIのページネーションをラップする非同期反復可能オブジェクトを返します
     * nextの引数に文字列 'reset' を渡すと最初のインデックスに戻ることができます。
     * @param initialUrl 最初にリクエストするURL
     * @param params リクエストのオプション
     */
    protected paginationGenerator<T extends any[]>(url: string, params?: options.PaginationOptions): AsyncIterableIterator<T | "reset">;
    /**
     * 与えられた認証情報をもとに新しいアクセストークンを発行します。
     * @param client_id 登録されたAPIクライアントを特定するためのID
     * @param client_secret 登録されたAPIクライアントを認証するための秘密鍵
     * @param code リダイレクト用のURLに付与された、アクセストークンと交換するための文字列
     * @return アクセストークン
     */
    fetchAccessToken: (client_id: string, client_secret: string, code: string) => Promise<AccessToken>;
    /**
     * 指定されたアクセストークンを失効させ、それ以降利用できないようにします。
     * @param token アクセストークン
     * @return 空のオブジェクト
     */
    deleteAccessToken: (token: string) => Promise<void>;
    /**
     * コメントを取得します。
     * @param comment_id コメントのID
     * @return コメントのエンティティを返します
     */
    fetchComment: (comment_id: string) => Promise<Comment>;
    /**
     * コメントを更新します。
     * @param comment_id コメントのID
     * @param body コメントの内容を表すMarkdown形式の文字列
     */
    updateComment: (comment_id: string, body: string) => Promise<Comment>;
    /**
     * コメントを削除します。
     * @param comment_id コメントのID
     * @return 空のオブジェクト
     */
    deleteComment: (comment_id: string) => Promise<void>;
    /**
     * コメントに付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param comment_id コメントID
     * @return 絵文字リアクション
     */
    fetchCommentReactions: (comment_id: string) => Promise<Reaction[]>;
    /**
     * コメントに絵文字リアクションを付けます。
     * @param comment_id コメントID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createCommentReaction: (comment_id: string, name: string) => Promise<Reaction>;
    /**
     * コメントから絵文字リアクションを削除します。
     * @param comment_id コメントID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteCommentReaction: (comment_id: string, name: string) => Promise<Reaction>;
    /**
     * タグ一覧を作成日時の降順で返します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @param options.sort 並び順 (countで投稿数順、nameで名前順)
     * @return タグ一覧を返す非同期反復可能オブジェクト
     */
    fetchTags: (options?: options.FetchTagsOptions | undefined) => Promise<AsyncIterableIterator<"reset" | Tag[]>>;
    /**
     * タグを取得します。
     * @param tagId タグのID
     * @return タグ
     */
    fetchTag: (tag_id: string) => Promise<Tag>;
    /**
     * タグをフォローしているかどうかを調べます。
     * @param tag_id タグのID
     * @return タグ
     */
    fetchTagFollowing: (tag_id: string) => Promise<Tag>;
    /**
     * タグをフォローします。
     * @param tag_id タグのID
     * @return 空のオブジェクト
     */
    followTag: (tag_id: string) => Promise<Tag>;
    /**
     * タグをフォローします。
     * @param tag_id タグのID
     * @return 空のオブジェクト
     */
    unfollowTag: (tag_id: string) => Promise<void>;
    /**
     * 指定されたタグが付けられた投稿一覧を、タグを付けた日時の降順で返します。
     * @param tag_id タグID
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchTaggedItems: (tag_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Item[]>;
    /**
     * チーム内のテンプレート一覧を返します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return テンプレート一覧を返す非同期反復可能オブジェクト
     */
    fetchTemplates: (options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Template[]>;
    /**
     * テンプレートを取得します。
     * @param template_id テンプレートID
     * @return テンプレート
     */
    fetchTempalte: (template_id: string) => Promise<Template>;
    /**
     * [実験的] タグを検索します
     * @param q 検索クエリ文字列
     * @return タグの配列
     */
    searchTags: (q: string) => Promise<SearchTagResult[]>;
    /**
     * 新しくテンプレートを作成します。
     * @param options.body テンプレートの本文
     * @param options.name テンプレートを判別するための名前
     * @param options.tags タグ一覧
     * @param options.title 生成される投稿のタイトルの雛形
     * @return テンプレート
     */
    createTemplate: (options: options.CreateTemplateOptions) => Promise<Template>;
    /**
     * テンプレートを更新します。
     * @param options.body テンプレートの本文
     * @param options.name テンプレートを判別するための名前
     * @param options.tags タグ一覧
     * @param options.title 生成される投稿のタイトルの雛形
     * @return テンプレート
     */
    updateTempalte: (options?: options.CreateTemplateOptions | undefined) => Promise<Template>;
    /**
     * テンプレートを削除します。
     * @param template_id テンプレートID
     * @return 空のオブジェクト
     */
    deleteTemplate: (template_id: string) => Promise<void>;
    /**
     * チーム内に存在するプロジェクト一覧をプロジェクト作成日時の降順で返します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return プロジェクト一覧
     */
    fetchProjects: (options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Project[]>;
    /**
     * プロジェクトを返します。
     * @param project_id プロジェクトID
     * @return プロジェクト
     */
    fetchProject: (project_id: string) => Promise<Project>;
    /**
     * プロジェクトを新たに作成します。
     * @param options.archived このプロジェクトが進行中かどうか
     * @param options.body Markdown形式の本文
     * @param options.name プロジェクト名
     * @param options.tags 投稿に付いたタグ一覧
     * @return プロジェクト
     */
    createProject: (options: options.CreateProjectOptions) => Promise<Project>;
    /**
     * プロジェクトを更新します。
     * @param options.archived このプロジェクトが進行中かどうか
     * @param options.body Markdown形式の本文
     * @param options.name プロジェクト名
     * @param options.tags 投稿に付いたタグ一覧
     * @return プロジェクト
     */
    updateProject: (options?: options.CreateProjectOptions | undefined) => Promise<Project>;
    /**
     * プロジェクトを削除します。
     * @param project_id プロジェクトID
     * @return 空のオブジェクト
     */
    deleteProject: (project_id: string) => Promise<void>;
    /**
     * プロジェクトに付けられたコメント一覧を投稿日時の降順で取得します。
     * @param project_id プロジェクトのID
     * @return コメント一覧
     */
    fetchProjectComments: (project_id: string) => Promise<Comment[]>;
    /**
     * プロジェクトに対してコメントを投稿します。
     * @param project_id 投稿のID
     * @param body コメントの内容を表すMarkdown形式の文字列
     * @return 投稿したコメント
     */
    createProjectComment: (project_id: string, body: string) => Promise<Comment[]>;
    /**
     * プロジェクトに付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param project_id プロジェクトID
     * @return 絵文字リアクション一覧
     */
    fetchProjectReactions: (project_id: string) => Promise<Reaction[]>;
    /**
     * プロジェクトに絵文字リアクションを付けます。
     * @param project_id プロジェクトID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createProjectReaction: (project_id: string, name: string) => Promise<Reaction>;
    /**
     * プロジェクトから絵文字リアクションを削除します。
     * @param project_id プロジェクトID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteProjectReaction: (project_id: string, name: string) => Promise<Reaction>;
    /**
     * 全てのユーザの一覧を作成日時の降順で取得します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchUsers: (options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | User[]>;
    /**
     * ユーザを取得します。
     * @param user_id ユーザーID
     * @return ユーザー
     */
    fetchUser: (user_id: string) => Promise<User>;
    /**
     * ユーザがフォローしているユーザ一覧を取得します。
     * @param user_id ユーザーID
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchUserFollowees: (user_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | User[]>;
    /**
     * ユーザをフォローしているユーザ一覧を取得します。
     * @param user_id ユーザーID
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchUserFollowers: (user_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | User[]>;
    /**
     * 指定されたユーザの投稿一覧を、作成日時の降順で返します。
     * @param user_id ユーザID
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchUserItems: (user_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Item[]>;
    /**
     * 指定されたユーザがストックした投稿一覧を、ストックした日時の降順で返します。
     * @param user_id ユーザID
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchUserStocks: (user_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Item[]>;
    /**
     * ユーザがフォローしているタグ一覧をフォロー日時の降順で返します。
     * @param user_id ユーザーID
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return タグ一覧を返す非同期反復可能オブジェクト
     */
    fetchUserFollowingTags: (user_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Tag[]>;
    /**
     * ユーザをフォローしている場合に204を返します。
     * @param user_id ユーザーID
     * @return 空のオブジェクト
     */
    fetchIfUserFollowing: (user_id: string) => Promise<void>;
    /**
     * ユーザをフォローします
     * @param user_id ユーザーID
     * @return 空のオブジェクト
     */
    followUser: (user_id: string) => Promise<void>;
    /**
     * ユーザへのフォローを外します。
     * @param user_id ユーザーID
     * @return 空のオブジェクト
     */
    unfollowUser: (user_id: string) => Promise<void>;
    /**
     * 投稿の一覧を作成日時の降順で返します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @param options.query 検索クエリ
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchItems: (options?: options.FetchItemsOptions | undefined) => AsyncIterableIterator<"reset" | Item[]>;
    /**
     * 投稿を取得します。
     * @param item_id 投稿ID
     * @return 投稿
     */
    fetchItem: (item_id: string) => Promise<Item>;
    /**
     * 新たに投稿を作成します。
     * @param options.body Markdown形式の本文
     * @param options.coediting この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効)
     * @param options.gist 本文中のコードをGistに投稿するかどうか (GitHub連携を有効化している場合のみ有効)
     * @param options.groupUrlName この投稿を公開するグループの url_name (null で全体に公開。Qiita:Teamでのみ有効)
     * @param options.private 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効)
     * @param options.tag 投稿に付いたタグ一覧
     * @param options.title 投稿のタイトル
     * @param options.tweet Twitterに投稿するかどうか (Twitter連携を有効化している場合のみ有効)
     * @return 投稿
     */
    createItem: (options: options.CreateItemOptions) => Promise<Item>;
    /**
     * 投稿を更新します。
     * @param item_id 投稿のID
     * @param options.coediting この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効)
     * @param options.groupUrlName この投稿を公開するグループの url_name (null で全体に公開。Qiita:Teamでのみ有効)
     * @param options.private 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効)
     * @param options.tag 投稿に付いたタグ一覧
     * @param options.title 投稿のタイトル
     * @return 投稿
     */
    updateItem: (item_id: string, options: options.CreateItemOptions) => Promise<Item>;
    /**
     * 投稿を削除します。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    deleteItem: (item_id: string) => Promise<void>;
    /**
     * 投稿に「いいね！」を付けているかどうかを調べます。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    fetchIfItemLiked: (item_id: string) => Promise<void>;
    /**
     * 投稿に「いいね！」を付けます。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    likeItem: (item_id: string) => Promise<void>;
    /**
     * 投稿への「いいね！」を取り消します。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    unlikeItem: (item_id: string) => Promise<void>;
    /**
     * 投稿をストックしているかどうかを調べます。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    fetchIfItemStocked: (item_id: string) => Promise<void>;
    /**
     * 投稿をストックします。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    stockItem: (item_id: string) => Promise<void>;
    /**
     * 投稿をストックから取り除きます。
     * @param item_id 投稿ID
     * @return 空のオブジェクト
     */
    unstockItem: (item_id: string) => Promise<void>;
    /**
     * 記事に付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param item_id 投稿ID
     * @return 絵文字リアクション
     */
    fetchItemReactions: (item_id: string) => Promise<Reaction[]>;
    /**
     * 記事に絵文字リアクションを付けます。
     * @param item_id 投稿ID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createItemReaction: (item_id: string, name: string) => Promise<Reaction>;
    /**
     * 記事から絵文字リアクションを削除します。
     * @param item_id 投稿ID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteItemReaction: (item_id: string, name: string) => Promise<Reaction>;
    /**
     * 投稿につけられた「いいね！」を作成日時の降順で返します。
     * @param item_id 投稿のID
     * @return いいね！エンティティを返します
     */
    fetchItemLikes: (item_id: string) => Promise<Like[]>;
    /**
     * 投稿をストックしているユーザ一覧を、ストックした日時の降順で返します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧を返す非同期反復可能オブジェクト
     */
    fetchItemStockers: (item_id: string, options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | User[]>;
    /**
     * 投稿に付けられたコメント一覧を投稿日時の降順で取得します。
     * @param item_id 投稿のID
     * @return コメント一覧
     */
    fetchItemComments: (item_id: string) => Promise<Comment[]>;
    /**
     * 投稿に対してコメントを投稿します。
     * @param item_id 投稿のID
     * @param body コメントの内容を表すMarkdown形式の文字列
     * @return 投稿したコメント
     */
    createItemComment: (item_id: string, body: string) => Promise<Comment[]>;
    /**
     * 投稿にタグを追加します。Qiita:Teamでのみ有効です。
     * @param item_id 投稿のID
     * @param name タグを特定するための一意な名前
     * @param versions (説明なし)
     */
    addItemTag: (item_id: string, name: string, versions: string[]) => Promise<Tagging>;
    /**
     * 投稿から指定されたタグを取り除きます。Qiita:Teamでのみ有効です。
     * @param item_id 投稿のID
     * @param tagId タギングのID
     * @return 空のオブジェクト
     */
    removeItemTag: (item_id: string, tagId: string) => Promise<void>;
    /**
     * ユーザが所属している全てのチームを、チーム作成日時の降順で返します。
     * @return チーム一覧
     */
    fetchTeams: () => Promise<Team[]>;
    /**
     * 招待中のメンバーの一覧を返します
     * @return 招待
     */
    fetchTeamInvitations: () => Promise<TeamInvitation>;
    /**
     * チームにメンバーを招待します
     * @return 招待
     */
    createTeamInvitations: () => Promise<TeamInvitation>;
    /**
     * 招待を取り消します
     * @return 空のオブジェクト
     */
    deleteTeamInvitation: () => Promise<void>;
    /**
     * アクセストークンに紐付いたユーザを返します。
     * @return 認証中のユーザ
     */
    fetchAuthenticatedUser: () => Promise<AuthenticatedUser>;
    /**
     * 認証中のユーザの投稿の一覧を作成日時の降順で返します。
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchAuthenticatedUserItems: (options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Item[]>;
    /**
     * `Qiita.fetchAuthenticatedUser` のシノニムです
     * @return 認証中のユーザ
     */
    fetchMe: () => Promise<AuthenticatedUser>;
    /**
     * `Qiita.fetchAuthenticatedUserItems` のシノニムです
     * @param options.page ページ番号 (1から100まで)
     * @param options.per_page 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧を返す非同期反復可能オブジェクト
     */
    fetchMyItems: (options?: options.PaginationOptions | undefined) => AsyncIterableIterator<"reset" | Item[]>;
}
